package ru.redguy.dynamicshop;

import net.milkbowl.vault.economy.Economy;
import org.bukkit.configuration.serialization.ConfigurationSerialization;
import org.bukkit.plugin.RegisteredServiceProvider;
import org.bukkit.plugin.java.JavaPlugin;
import ru.redguy.dynamicshop.api.ShopItem;
import ru.redguy.dynamicshop.commands.AddShopItemCommand;
import ru.redguy.dynamicshop.commands.ShopCommand;
import org.jetbrains.annotations.NotNull;

public final class DynamicShop extends JavaPlugin {

    static {
        ConfigurationSerialization.registerClass(ShopItem.class, "ShopItem");
    }

    private static DynamicShop instance;
    private Economy economy;

    @NotNull
    public static DynamicShop getInstance() {
        if (instance == null) {
            throw new IllegalStateException("Plugin instance not initialized!");
        }
        return instance;
    }

    public Economy getEconomy() {
        return economy;
    }

    @Override
    public void onEnable() {
        instance = this;
        
        // Save default config if it doesn't exist
        saveDefaultConfig();
        
        // Setup economy
        if (!setupEconomy()) {
            getLogger().severe("Disabled due to no Vault dependency found!");
            getServer().getPluginManager().disablePlugin(this);
            return;
        }

        // Register commands
        registerCommands();
        
        getLogger().info("DynamicShop has been enabled!");
    }

    @Override
    public void onDisable() {
        getLogger().info("DynamicShop has been disabled!");
    }

    private boolean setupEconomy() {
        if (getServer().getPluginManager().getPlugin("Vault") == null) {
            return false;
        }
        RegisteredServiceProvider<Economy> rsp = getServer().getServicesManager().getRegistration(Economy.class);
        if (rsp == null) {
            return false;
        }
        economy = rsp.getProvider();
        return economy != null;
    }

    private void registerCommands() {
        try {
            getServer().getCommandMap().register("shop", "dynamicshop", new ShopCommand("shop"));
            getServer().getCommandMap().register("additem", "dynamicshop", new AddShopItemCommand("additem"));
            getServer().getCommandMap().register("reloadshop", "dynamicshop", new AddShopItemCommand("reloadshop"));
            getLogger().info("Commands registered successfully!");
        } catch (Exception e) {
            getLogger().severe("Failed to register commands: " + e.getMessage());
        }
    }
}
