package ru.redguy.dynamicshop.commands;

import org.bukkit.ChatColor;
import org.bukkit.command.Command;
import org.bukkit.command.CommandSender;
import org.bukkit.entity.Player;
import org.bukkit.inventory.ItemStack;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;
import ru.redguy.dynamicshop.api.Database;
import ru.redguy.dynamicshop.api.ShopItem;
import ru.redguy.dynamicshop.gui.ShopGuiSell;

import java.util.Collections;
import java.util.List;

public class AddShopItemCommand extends Command {
    public AddShopItemCommand(@NotNull String name) {
        super(name);
        this.setDescription("Add an item to the shop");
        this.setUsage("§c/additem <price>");
        this.setPermission("dynshop.add");
    }

    @Override
    public boolean execute(@NotNull CommandSender sender, @NotNull String commandLabel, @NotNull String[] args) {
        if (!(sender instanceof Player)) {
            sender.sendMessage(ChatColor.RED + "This command can only be used by players!");
            return true;
        }

        Player player = (Player) sender;

        if (!player.hasPermission("dynshop.add")) {
            player.sendMessage(ChatColor.RED + "You don't have permission to add items to the shop!");
            return true;
        }

        if (args.length != 1) {
            player.sendMessage(this.getUsage());
            return true;
        }

        ItemStack itemInHand = player.getInventory().getItemInMainHand();
        if (itemInHand == null || itemInHand.getType().isAir()) {
            player.sendMessage(ChatColor.RED + "You must hold an item to add it to the shop!");
            return true;
        }

        double price;
        try {
            price = Double.parseDouble(args[0].replace(',', '.'));
            if (price < 0) {
                player.sendMessage(ChatColor.RED + "Price cannot be negative!");
                return true;
            }
        } catch (NumberFormatException e) {
            player.sendMessage(ChatColor.RED + "Invalid price format! Use numbers only.");
            return true;
        }

        try {
            ShopItem shopItem = new ShopItem(itemInHand.clone(), price);
            Database.getInstance().addItem(shopItem);
            ShopGuiSell.update();
            player.sendMessage(ChatColor.GREEN + "Item successfully added to the shop for " + price + "!");
        } catch (Exception e) {
            player.sendMessage(ChatColor.RED + "Failed to add item to the shop: " + e.getMessage());
        }

        return true;
    }

    @Override
    public @NotNull List<String> tabComplete(@NotNull CommandSender sender, @NotNull String alias, @NotNull String[] args) {
        return Collections.emptyList(); // No tab completion for price
    }

    @Override
    public @Nullable String getPermission() {
        return "dynshop.add";
    }
}
