package ru.redguy.dynamicshop.commands;

import com.google.common.collect.Lists;
import org.bukkit.command.Command;
import org.bukkit.command.CommandSender;
import org.bukkit.entity.Player;
import org.jetbrains.annotations.NotNull;
import ru.redguy.dynamicshop.gui.ShopGuiBuy;
import ru.redguy.dynamicshop.gui.ShopGuiSell;
import org.bukkit.ChatColor;

import java.util.Arrays;
import java.util.List;
import java.util.stream.Collectors;

public class ShopCommand extends Command {
    private static final String[] SUBCOMMANDS = {"sell", "buy"};
    
    public ShopCommand(@NotNull String name) {
        super(name);
        this.setDescription("Main shop command");
        this.setUsage("§c/shop <sell|buy>");
        this.setPermission("dynshop.use");
    }

    @Override
    public boolean execute(@NotNull CommandSender sender, @NotNull String commandLabel, @NotNull String[] args) {
        if (!(sender instanceof Player)) {
            sender.sendMessage(ChatColor.RED + "This command can only be used by players!");
            return true;
        }

        Player player = (Player) sender;
        
        if (!player.hasPermission("dynshop.use")) {
            player.sendMessage(ChatColor.RED + "You don't have permission to use this command!");
            return true;
        }

        if (args.length != 1) {
            player.sendMessage(this.getUsage());
            return true;
        }

        String subCommand = args[0].toLowerCase();
        switch (subCommand) {
            case "sell":
                ShopGuiSell.open(player);
                break;
            case "buy":
                ShopGuiBuy.open(player);
                break;
            default:
                player.sendMessage(this.getUsage());
                break;
        }
        
        return true;
    }

    @Override
    public @NotNull List<String> tabComplete(@NotNull CommandSender sender, @NotNull String alias, @NotNull String[] args) throws IllegalArgumentException {
        if (!(sender instanceof Player) || !sender.hasPermission("dynshop.use") || args.length != 1) {
            return Lists.newArrayList();
        }
        
        return Arrays.stream(SUBCOMMANDS)
                .filter(s -> s.toLowerCase().startsWith(args[0].toLowerCase()))
                .collect(Collectors.toList());
    }
}
