package ru.redguy.dynamicshop.gui;

import me.filoghost.chestcommands.api.Menu;
import org.bukkit.ChatColor;
import org.bukkit.entity.Player;
import org.jetbrains.annotations.NotNull;
import ru.redguy.dynamicshop.DynamicShop;
import ru.redguy.dynamicshop.gui.icons.ItemIconBuy;

public class ShopGuiBuy {
    private static final int ROWS = 6;
    private static final int COLUMNS = 9;
    private static final int ITEM_ROWS = 3;
    private static final Menu menu;

    static {
        try {
            menu = Menu.create(DynamicShop.getInstance(), ChatColor.DARK_GREEN + "Shop | Buy", ROWS);
            populateIcons();
        } catch (Exception e) {
            DynamicShop.getInstance().getLogger().severe("Failed to initialize shop buy menu: " + e.getMessage());
            throw new ExceptionInInitializerError(e);
        }
    }

    private ShopGuiBuy() {
        // Private constructor to prevent instantiation
    }

    public static void open(@NotNull Player player) {
        if (player == null) {
            throw new IllegalArgumentException("Player cannot be null");
        }

        try {
            menu.open(player);
        } catch (Exception e) {
            player.sendMessage(ChatColor.RED + "Failed to open shop menu!");
            DynamicShop.getInstance().getLogger().severe("Failed to open shop buy menu for " + player.getName() + ": " + e.getMessage());
        }
    }

    public static void update() {
        try {
            menu.refreshOpenViews();
        } catch (Exception e) {
            DynamicShop.getInstance().getLogger().severe("Failed to update shop buy menu: " + e.getMessage());
        }
    }

    private static void populateIcons() {
        try {
            for (int row = 0; row < ITEM_ROWS; row++) {
                for (int column = 0; column < COLUMNS; column++) {
                    int slot = row * COLUMNS + column;
                    menu.setIcon(row, column, new ItemIconBuy(slot));
                }
            }
        } catch (Exception e) {
            DynamicShop.getInstance().getLogger().severe("Failed to populate shop buy menu icons: " + e.getMessage());
            throw new RuntimeException("Failed to populate shop buy menu icons", e);
        }
    }
}
