package ru.redguy.dynamicshop.gui.icons;

import me.filoghost.chestcommands.api.Icon;
import me.filoghost.chestcommands.api.MenuView;
import net.kyori.adventure.text.Component;
import net.kyori.adventure.text.format.TextColor;
import org.bukkit.ChatColor;
import org.bukkit.Material;
import org.bukkit.entity.Player;
import org.bukkit.inventory.ItemStack;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;
import ru.redguy.dynamicshop.DynamicShop;
import ru.redguy.dynamicshop.api.Database;
import ru.redguy.dynamicshop.api.ShopItem;
import ru.redguy.dynamicshop.gui.ShopGuiBuy;
import ru.redguy.dynamicshop.gui.ShopGuiSell;

import java.math.BigDecimal;
import java.math.RoundingMode;
import java.util.ArrayList;
import java.util.List;
import java.util.logging.Level;

public class ItemIconSell implements Icon {
    private static final double MIN_PRICE = 1.0;
    private static final double PRICE_DECREASE = 0.1;
    private static final int PRICE_DECIMALS = 2;
    private static final TextColor PRICE_LABEL_COLOR = TextColor.color(255, 255, 255);
    private static final TextColor PRICE_VALUE_COLOR = TextColor.color(255, 100, 0);

    private final int index;

    public ItemIconSell(int index) {
        if (index < 0) {
            throw new IllegalArgumentException("Index cannot be negative");
        }
        this.index = index;
    }

    @Override
    public @Nullable ItemStack render(@NotNull Player player) {
        try {
            ShopItem item = Database.getInstance().getItem(index);
            if (item == null || item.getItem().getType() == Material.AIR) {
                return null;
            }

            ItemStack stack = item.getItem().clone();
            List<Component> lore = new ArrayList<>();
            lore.add(Component.text("Price: ")
                    .color(PRICE_LABEL_COLOR)
                    .append(Component.text(String.format("%.2f", item.getPrice()))
                    .color(PRICE_VALUE_COLOR)));
            stack.lore(lore);
            return stack;
        } catch (Exception e) {
            DynamicShop.getInstance().getLogger().log(Level.SEVERE, 
                "Failed to render sell icon for index " + index, e);
            return null;
        }
    }

    @Override
    public void onClick(@NotNull MenuView menuView, @NotNull Player player) {
        try {
            ShopItem item = Database.getInstance().getItem(index);
            if (!validateTransaction(player, item)) {
                return;
            }

            // Process the transaction
            processTransaction(player, item);

            // Update the item price and refresh menus
            updateItemPrice(item);
            refreshMenus();

        } catch (Exception e) {
            player.sendMessage(ChatColor.RED + "Failed to process sale!");
            DynamicShop.getInstance().getLogger().log(Level.SEVERE, 
                "Failed to process sell transaction for player " + player.getName(), e);
        }
    }

    private boolean validateTransaction(@NotNull Player player, @Nullable ShopItem item) {
        if (item == null || item.getItem().getType() == Material.AIR) {
            return false;
        }

        if (item.getPrice() <= MIN_PRICE) {
            player.sendMessage(ChatColor.RED + "Item price is too low!");
            return false;
        }

        ItemStack requiredItem = item.getItem().clone();
        if (!player.getInventory().containsAtLeast(requiredItem, requiredItem.getAmount())) {
            player.sendMessage(ChatColor.RED + "You don't have enough items to sell!");
            return false;
        }

        return true;
    }

    private void processTransaction(@NotNull Player player, @NotNull ShopItem item) {
        player.getInventory().removeItem(item.getItem().clone());
        DynamicShop.getInstance().getEconomy().depositPlayer(player, item.getPrice());
        player.sendMessage(ChatColor.GREEN + "Successfully sold item for " + 
            ChatColor.GOLD + String.format("%.2f", item.getPrice()));
    }

    private void updateItemPrice(@NotNull ShopItem item) {
        double newPrice = round(item.getPrice() - PRICE_DECREASE, PRICE_DECIMALS);
        Database.getInstance().setItem(index, new ShopItem(item.getItem(), newPrice));
    }

    private void refreshMenus() {
        ShopGuiSell.update();
        ShopGuiBuy.update();
    }

    private static double round(double value, int places) {
        if (places < 0) {
            throw new IllegalArgumentException("Decimal places cannot be negative");
        }

        try {
            BigDecimal bd = BigDecimal.valueOf(value);
            bd = bd.setScale(places, RoundingMode.HALF_DOWN);
            return bd.doubleValue();
        } catch (NumberFormatException e) {
            throw new IllegalArgumentException("Failed to round value: " + value, e);
        }
    }
}
